# Metallurgy

![Tests](https://github.com/Robert-Forrest/metallurgy/actions/workflows/tests.yml/badge.svg)

The Metallurgy package enables calculation of approximate properties of alloy
mixtures, based on the linear mixture of elemental properties. 


